summaryrefslogtreecommitdiffstats
path: root/src/gui/general
diff options
context:
space:
mode:
Diffstat (limited to 'src/gui/general')
-rw-r--r--src/gui/general/BaseTool.h2
-rw-r--r--src/gui/general/CanvasItemGC.h4
-rw-r--r--src/gui/general/EditView.cpp24
-rw-r--r--src/gui/general/EditViewBase.cpp26
-rw-r--r--src/gui/general/EditViewBase.h2
-rw-r--r--src/gui/general/LinedStaff.cpp32
-rw-r--r--src/gui/general/LinedStaff.h50
-rw-r--r--src/gui/general/MidiPitchLabel.cpp2
-rw-r--r--src/gui/general/PresetGroup.cpp22
-rw-r--r--src/gui/general/PresetHandlerDialog.cpp20
-rw-r--r--src/gui/general/RosegardenCanvasView.cpp16
-rw-r--r--src/gui/general/RosegardenScrollView.cpp6
12 files changed, 103 insertions, 103 deletions
diff --git a/src/gui/general/BaseTool.h b/src/gui/general/BaseTool.h
index fa3027b..2c1eab1 100644
--- a/src/gui/general/BaseTool.h
+++ b/src/gui/general/BaseTool.h
@@ -58,7 +58,7 @@ public:
/**
* Is called by the parent View (EditView or SegmentCanvas) when
* the tool is set as current.
- * Add any setup here (e.g. setting the mouse cursor shape)
+ * Add any setup here (e.g. setting the mouse cursor tqshape)
*/
virtual void ready();
diff --git a/src/gui/general/CanvasItemGC.h b/src/gui/general/CanvasItemGC.h
index 681e021..50bd21f 100644
--- a/src/gui/general/CanvasItemGC.h
+++ b/src/gui/general/CanvasItemGC.h
@@ -52,10 +52,10 @@ namespace Rosegarden
*
* However, if the SegmentItem deletes its repeat rectangle, then when
* the SegmentCanvas destruction occurs, the SegmentCanvas dtor will
- * get a list of all its children (TQCanvas::allItems()), containing
+ * get a list of all its tqchildren (TQCanvas::allItems()), containing
* both SegmentItems and their repeat rectangles. Deleting a
* SegmentItem will delete its repeat rectangle, which will still be
- * present in the all children list which the SegmentCanvas dtor is
+ * present in the all tqchildren list which the SegmentCanvas dtor is
* iterating over.
*
* So a solution is simply to push to-be-deleted repeat rectangles on
diff --git a/src/gui/general/EditView.cpp b/src/gui/general/EditView.cpp
index 0e66133..f1f5dbf 100644
--- a/src/gui/general/EditView.cpp
+++ b/src/gui/general/EditView.cpp
@@ -24,7 +24,7 @@
#include "EditView.h"
-#include <layout.h>
+#include <tqlayout.h>
#include "base/BaseProperties.h"
#include <klocale.h>
@@ -138,7 +138,7 @@ EditView::EditView(RosegardenGUIDoc *doc,
connect(m_controlRulers, TQT_SIGNAL(closeRequest(TQWidget*)),
this, TQT_SLOT(slotRemoveControlRuler(TQWidget*)));
- (dynamic_cast<TQBoxLayout*>(m_bottomBox->layout()))->setDirection(TQBoxLayout::BottomToTop);
+ (dynamic_cast<TQBoxLayout*>(m_bottomBox->tqlayout()))->setDirection(TQBoxLayout::BottomToTop);
// m_rulerBoxFiller is a white label used to keep m_rulerBox exactly
// above the scrolling part of the view (and never above the
@@ -154,7 +154,7 @@ EditView::EditView(RosegardenGUIDoc *doc,
m_grid->addLayout(gl, RULERS_ROW, m_mainCol);
m_grid->addMultiCellLayout(m_controlBox, CONTROLS_ROW, CONTROLS_ROW, 0, 1);
- m_controlBox->setAlignment(AlignRight);
+ m_controlBox->tqsetAlignment(AlignRight);
// m_grid->addWidget(m_controlRulers, CONTROLRULER_ROW, 2);
m_controlRulers->hide();
@@ -169,7 +169,7 @@ EditView::~EditView()
void EditView::updateBottomWidgetGeometry()
{
- getBottomWidget()->layout()->invalidate();
+ getBottomWidget()->tqlayout()->tqinvalidate();
getBottomWidget()->updateGeometry();
getCanvasView()->updateBottomWidgetGeometry();
}
@@ -891,9 +891,9 @@ EditView::setupAddControlRulerMenu()
TQString hexValue;
hexValue.sprintf("(0x%x)", it->getControllerValue());
- itemStr = i18n("%1 Controller %2 %3").arg(strtoqstr(it->getName()))
- .arg(it->getControllerValue())
- .arg(hexValue);
+ itemStr = i18n("%1 Controller %2 %3").tqarg(strtoqstr(it->getName()))
+ .tqarg(it->getControllerValue())
+ .tqarg(hexValue);
} else if (it->getType() == PitchBend::EventType)
itemStr = i18n("Pitch Bend");
@@ -1114,10 +1114,10 @@ EditView::createInsertPitchActionMenu()
insertPitchAction =
new KAction
- (flat.arg(notePitchNames[i]),
+ (flat.tqarg(notePitchNames[i]),
CTRL + SHIFT + notePitchKeys[octave][i],
TQT_TQOBJECT(this), TQT_SLOT(slotInsertNoteFromAction()), actionCollection(),
- TQString("insert_%1_flat%2").arg(i).arg(octaveSuffix).ascii());
+ TQString("insert_%1_flat%2").tqarg(i).tqarg(octaveSuffix).ascii());
menu->insert(insertPitchAction);
}
@@ -1127,7 +1127,7 @@ EditView::createInsertPitchActionMenu()
(notePitchNames[i],
notePitchKeys[octave][i],
TQT_TQOBJECT(this), TQT_SLOT(slotInsertNoteFromAction()), actionCollection(),
- TQString("insert_%1%2").arg(i).arg(octaveSuffix).ascii());
+ TQString("insert_%1%2").tqarg(i).tqarg(octaveSuffix).ascii());
menu->insert(insertPitchAction);
@@ -1137,10 +1137,10 @@ EditView::createInsertPitchActionMenu()
insertPitchAction =
new KAction
- (sharp.arg(notePitchNames[i]),
+ (sharp.tqarg(notePitchNames[i]),
SHIFT + notePitchKeys[octave][i],
TQT_TQOBJECT(this), TQT_SLOT(slotInsertNoteFromAction()), actionCollection(),
- TQString("insert_%1_sharp%2").arg(i).arg(octaveSuffix).ascii());
+ TQString("insert_%1_sharp%2").tqarg(i).tqarg(octaveSuffix).ascii());
menu->insert(insertPitchAction);
}
diff --git a/src/gui/general/EditViewBase.cpp b/src/gui/general/EditViewBase.cpp
index 4318646..dda2c76 100644
--- a/src/gui/general/EditViewBase.cpp
+++ b/src/gui/general/EditViewBase.cpp
@@ -24,7 +24,7 @@
#include "EditViewBase.h"
-#include <layout.h>
+#include <tqlayout.h>
#include <kapplication.h>
#include <klocale.h>
@@ -311,7 +311,7 @@ EditViewBase::makeViewLocalPropertyPrefix()
void EditViewBase::paintEvent(TQPaintEvent* e)
{
// It is possible for this function to be called re-entrantly,
- // because a re-layout procedure may deliberately ask the event
+ // because a re-tqlayout procedure may deliberately ask the event
// loop to process some more events so as to keep the GUI looking
// responsive. If that happens, we remember the events that came
// in in the middle of one paintEvent call and process their union
@@ -362,7 +362,7 @@ void EditViewBase::paintEvent(TQPaintEvent* e)
//
// If we have more than one segment modified, we need to update
// them all at once with the same time range, otherwise we can run
- // into problems when the layout of one depends on the others. So
+ // into problems when the tqlayout of one depends on the others. So
// we use updateStart/End to calculate a bounding range for all
// modifications.
@@ -374,12 +374,12 @@ void EditViewBase::paintEvent(TQPaintEvent* e)
Segment* segment = m_segments[i];
unsigned int refreshStatusId = m_segmentsRefreshStatusIds[i];
- SegmentRefreshStatus &refreshStatus =
- segment->getRefreshStatus(refreshStatusId);
+ SegmentRefreshtqStatus &refreshtqStatus =
+ segment->getRefreshtqStatus(refreshStatusId);
- if (refreshStatus.needsRefresh() && isCompositionModified()) {
+ if (refreshtqStatus.needsRefresh() && isCompositionModified()) {
- // if composition is also modified, relayout everything
+ // if composition is also modified, retqlayout everything
refreshSegment(0);
segmentsToUpdate = 0;
break;
@@ -392,10 +392,10 @@ void EditViewBase::paintEvent(TQPaintEvent* e)
m_timeSigNotifier->reset();
break;
- } else if (refreshStatus.needsRefresh()) {
+ } else if (refreshtqStatus.needsRefresh()) {
- timeT startTime = refreshStatus.from(),
- endTime = refreshStatus.to();
+ timeT startTime = refreshtqStatus.from(),
+ endTime = refreshtqStatus.to();
if (segmentsToUpdate == 0 || startTime < updateStart) {
updateStart = startTime;
@@ -406,7 +406,7 @@ void EditViewBase::paintEvent(TQPaintEvent* e)
singleSegment = segment;
++segmentsToUpdate;
- refreshStatus.setNeedsRefresh(false);
+ refreshtqStatus.setNeedsRefresh(false);
m_needUpdate = true;
}
}
@@ -518,13 +518,13 @@ void EditViewBase::initSegmentRefreshStatusIds()
bool EditViewBase::isCompositionModified()
{
- return getDocument()->getComposition().getRefreshStatus
+ return getDocument()->getComposition().getRefreshtqStatus
(m_compositionRefreshStatusId).needsRefresh();
}
void EditViewBase::setCompositionModified(bool c)
{
- getDocument()->getComposition().getRefreshStatus
+ getDocument()->getComposition().getRefreshtqStatus
(m_compositionRefreshStatusId).setNeedsRefresh(c);
}
diff --git a/src/gui/general/EditViewBase.h b/src/gui/general/EditViewBase.h
index ef70384..aaf6dbe 100644
--- a/src/gui/general/EditViewBase.h
+++ b/src/gui/general/EditViewBase.h
@@ -311,7 +311,7 @@ protected:
protected slots:
/**
* save general Options like all bar positions and status as well
- * as the geometry and the recent file list to the configuration
+ * as the tqgeometry and the recent file list to the configuration
* file
*/
virtual void slotSaveOptions();
diff --git a/src/gui/general/MidiPitchLabel.cpp b/src/gui/general/MidiPitchLabel.cpp
index 51742c3..a103234 100644
--- a/src/gui/general/MidiPitchLabel.cpp
+++ b/src/gui/general/MidiPitchLabel.cpp
@@ -55,7 +55,7 @@ MidiPitchLabel::MidiPitchLabel(int pitch)
int baseOctave = config->readNumEntry("midipitchoctave", -2);
int octave = (int)(((float)pitch) / 12.0) + baseOctave;
- m_midiNote = notes[pitch % 12].arg(octave);
+ m_midiNote = notes[pitch % 12].tqarg(octave);
}
}
diff --git a/src/gui/general/PresetGroup.cpp b/src/gui/general/PresetGroup.cpp
index 2c39256..cb8efca 100644
--- a/src/gui/general/PresetGroup.cpp
+++ b/src/gui/general/PresetGroup.cpp
@@ -70,7 +70,7 @@ PresetGroup::PresetGroup() :
TQString language = KGlobal::locale()->language();
TQString presetFileName = TQString("%1/presets-%2.xml")
- .arg(m_presetDirectory).arg(language);
+ .tqarg(m_presetDirectory).tqarg(language);
if (!TQFileInfo(presetFileName).isReadable()) {
@@ -78,14 +78,14 @@ PresetGroup::PresetGroup() :
language.replace(TQRegExp("_.*$"), "");
presetFileName = TQString("%1/presets-%2.xml")
- .arg(m_presetDirectory).arg(language);
+ .tqarg(m_presetDirectory).tqarg(language);
if (!TQFileInfo(presetFileName).isReadable()) {
RG_DEBUG << "Failed to open " << presetFileName << endl;
presetFileName = TQString("%1/presets.xml")
- .arg(m_presetDirectory);
+ .tqarg(m_presetDirectory);
if (!TQFileInfo(presetFileName).isReadable()) {
@@ -247,10 +247,10 @@ PresetGroup::error(const TQXmlParseException& exception)
RG_DEBUG << "PresetGroup::error(): jubilation and glee, we have an error, whee!" << endl;
m_errorString = TQString("%1 at line %2, column %3: %4")
- .arg(exception.message())
- .arg(exception.lineNumber())
- .arg(exception.columnNumber())
- .arg(m_errorString);
+ .tqarg(exception.message())
+ .tqarg(exception.lineNumber())
+ .tqarg(exception.columnNumber())
+ .tqarg(m_errorString);
return TQXmlDefaultHandler::error(exception);
}
@@ -259,10 +259,10 @@ PresetGroup::fatalError(const TQXmlParseException& exception)
{
RG_DEBUG << "PresetGroup::fatalError(): double your jubilation, and triple your glee, a fatal error doth it be!" << endl;
m_errorString = TQString("%1 at line %2, column %3: %4")
- .arg(exception.message())
- .arg(exception.lineNumber())
- .arg(exception.columnNumber())
- .arg(m_errorString);
+ .tqarg(exception.message())
+ .tqarg(exception.lineNumber())
+ .tqarg(exception.columnNumber())
+ .tqarg(m_errorString);
return TQXmlDefaultHandler::fatalError(exception);
}
diff --git a/src/gui/general/PresetHandlerDialog.cpp b/src/gui/general/PresetHandlerDialog.cpp
index b97d581..9d9c897 100644
--- a/src/gui/general/PresetHandlerDialog.cpp
+++ b/src/gui/general/PresetHandlerDialog.cpp
@@ -27,7 +27,7 @@
#include "PresetHandlerDialog.h"
-#include <layout.h>
+#include <tqlayout.h>
#include <kapplication.h>
#include <klocale.h>
@@ -81,7 +81,7 @@ PresetHandlerDialog::initDialog()
TQFrame *frame = new TQFrame(vBox);
- TQGridLayout *layout = new TQGridLayout(frame, 6, 5, 10, 5);
+ TQGridLayout *tqlayout = new TQGridLayout(frame, 6, 5, 10, 5);
TQLabel *title = new TQLabel(i18n("Select preset track parameters for:"), frame);
if (m_fromNotation) title->setText(i18n("Create appropriate notation for:"));
@@ -114,14 +114,14 @@ PresetHandlerDialog::initDialog()
onlyNewSegments->setChecked(true);
}
- layout->addMultiCellWidget(title, 0, 0, 0, 1, AlignLeft);
- layout->addWidget(catlabel, 1, 0, AlignRight);
- layout->addWidget(m_categoryCombo, 1, 1);
- layout->addWidget(inslabel, 2, 0, AlignRight);
- layout->addWidget(m_instrumentCombo, 2, 1);
- layout->addWidget(plylabel, 3, 0, AlignRight);
- layout->addWidget(m_playerCombo, 3, 1);
- layout->addMultiCellWidget(scopeBox, 4, 4, 0, 1, AlignLeft);
+ tqlayout->addMultiCellWidget(title, 0, 0, 0, 1, AlignLeft);
+ tqlayout->addWidget(catlabel, 1, 0, AlignRight);
+ tqlayout->addWidget(m_categoryCombo, 1, 1);
+ tqlayout->addWidget(inslabel, 2, 0, AlignRight);
+ tqlayout->addWidget(m_instrumentCombo, 2, 1);
+ tqlayout->addWidget(plylabel, 3, 0, AlignRight);
+ tqlayout->addWidget(m_playerCombo, 3, 1);
+ tqlayout->addMultiCellWidget(scopeBox, 4, 4, 0, 1, AlignLeft);
populateCategoryCombo();
// try to set to same category used previously
diff --git a/src/gui/general/RosegardenCanvasView.cpp b/src/gui/general/RosegardenCanvasView.cpp
index 4893147..a806e8a 100644
--- a/src/gui/general/RosegardenCanvasView.cpp
+++ b/src/gui/general/RosegardenCanvasView.cpp
@@ -84,10 +84,10 @@ void RosegardenCanvasView::setBottomFixedWidget(TQWidget* w)
{
m_bottomWidget = w;
if (m_bottomWidget) {
- int lww = m_leftWidget ? m_leftWidget->sizeHint().width() : 0;
+ int lww = m_leftWidget ? m_leftWidget->tqsizeHint().width() : 0;
m_bottomWidget->reparent(this, 0, TQPoint(0, 0));
- m_bottomWidget->setSizePolicy(TQSizePolicy(TQSizePolicy::Preferred, TQSizePolicy::Fixed));
- setMargins(lww, 0, 0, m_bottomWidget->sizeHint().height());
+ m_bottomWidget->tqsetSizePolicy(TQSizePolicy(TQSizePolicy::Preferred, TQSizePolicy::Fixed));
+ setMargins(lww, 0, 0, m_bottomWidget->tqsizeHint().height());
}
}
@@ -399,7 +399,7 @@ void RosegardenCanvasView::updateBottomWidgetGeometry()
if (!m_bottomWidget)
return ;
- int bottomWidgetHeight = m_bottomWidget->sizeHint().height();
+ int bottomWidgetHeight = m_bottomWidget->tqsizeHint().height();
int leftWidgetWidth = 0;
if (m_leftWidget && m_leftWidget->isVisible()) {
@@ -447,10 +447,10 @@ void RosegardenCanvasView::setLeftFixedWidget(TQWidget* w)
{
m_leftWidget = w;
if (m_leftWidget) {
- int bwh = m_bottomWidget ? m_bottomWidget->sizeHint().height() : 0;
+ int bwh = m_bottomWidget ? m_bottomWidget->tqsizeHint().height() : 0;
m_leftWidget->reparent(this, 0, TQPoint(0, 0));
- m_leftWidget->setSizePolicy(TQSizePolicy(TQSizePolicy::Fixed, TQSizePolicy::Preferred));
- setMargins(m_leftWidget->sizeHint().width(), 0, 0, bwh);
+ m_leftWidget->tqsetSizePolicy(TQSizePolicy(TQSizePolicy::Fixed, TQSizePolicy::Preferred));
+ setMargins(m_leftWidget->tqsizeHint().width(), 0, 0, bwh);
}
}
@@ -467,7 +467,7 @@ void RosegardenCanvasView::updateLeftWidgetGeometry()
m_leftWidget->setFixedWidth(leftWidgetWidth);
int bottomWidgetHeight = m_bottomWidget ?
- m_bottomWidget->sizeHint().height() : 0;
+ m_bottomWidget->tqsizeHint().height() : 0;
setMargins(leftWidgetWidth, 0, 0, bottomWidgetHeight);
diff --git a/src/gui/general/RosegardenScrollView.cpp b/src/gui/general/RosegardenScrollView.cpp
index c3184da..815ab6b 100644
--- a/src/gui/general/RosegardenScrollView.cpp
+++ b/src/gui/general/RosegardenScrollView.cpp
@@ -75,8 +75,8 @@ void RosegardenScrollView::setBottomFixedWidget(TQWidget* w)
m_bottomWidget = w;
if (m_bottomWidget) {
m_bottomWidget->reparent(this, 0, TQPoint(0, 0));
- m_bottomWidget->setSizePolicy(TQSizePolicy(TQSizePolicy::Preferred, TQSizePolicy::Fixed));
- setMargins(0, 0, 0, m_bottomWidget->sizeHint().height());
+ m_bottomWidget->tqsetSizePolicy(TQSizePolicy(TQSizePolicy::Preferred, TQSizePolicy::Fixed));
+ setMargins(0, 0, 0, m_bottomWidget->tqsizeHint().height());
}
}
@@ -376,7 +376,7 @@ void RosegardenScrollView::updateBottomWidgetGeometry()
if (!m_bottomWidget)
return ;
- int bottomWidgetHeight = m_bottomWidget->sizeHint().height();
+ int bottomWidgetHeight = m_bottomWidget->tqsizeHint().height();
setMargins(0, 0, 0, bottomWidgetHeight);
TQRect r = frameRect();
diff --git a/src/gui/general/LinedStaff.cpp b/src/gui/general/LinedStaff.cpp
index 9156efe..ffaa28c 100644
--- a/src/gui/general/LinedStaff.cpp
+++ b/src/gui/general/LinedStaff.cpp
@@ -572,7 +572,7 @@ LinedStaff::getCanvasXForLeftOfRow(int row) const
}
void
-LinedStaff::sizeStaff(HorizontalLayoutEngine &layout)
+LinedStaff::sizeStaff(HorizontalLayoutEngine &tqlayout)
{
Profiler profiler("LinedStaff::sizeStaff", true);
@@ -582,19 +582,19 @@ LinedStaff::sizeStaff(HorizontalLayoutEngine &layout)
// RG_DEBUG << "LinedStaff::sizeStaff" << endl;
- int lastBar = layout.getLastVisibleBarOnStaff(*this);
+ int lastBar = tqlayout.getLastVisibleBarOnStaff(*this);
double xleft = 0, xright = 0;
bool haveXLeft = false;
- xright = layout.getBarPosition(lastBar) - 1;
+ xright = tqlayout.getBarPosition(lastBar) - 1;
TimeSignature currentTimeSignature;
- for (int barNo = layout.getFirstVisibleBarOnStaff(*this);
+ for (int barNo = tqlayout.getFirstVisibleBarOnStaff(*this);
barNo <= lastBar; ++barNo) {
- double x = layout.getBarPosition(barNo);
+ double x = tqlayout.getBarPosition(barNo);
if (!haveXLeft) {
xleft = x;
@@ -603,7 +603,7 @@ LinedStaff::sizeStaff(HorizontalLayoutEngine &layout)
double timeSigX = 0;
TimeSignature timeSig;
- bool isNew = layout.getTimeSignaturePosition(*this, barNo, timeSig, timeSigX);
+ bool isNew = tqlayout.getTimeSignaturePosition(*this, barNo, timeSig, timeSigX);
if (isNew && barNo < lastBar) {
currentTimeSignature = timeSig;
@@ -619,8 +619,8 @@ LinedStaff::sizeStaff(HorizontalLayoutEngine &layout)
insertBar(x,
((barNo == lastBar) ? 0 :
- (layout.getBarPosition(barNo + 1) - x)),
- layout.isBarCorrectOnStaff(*this, barNo - 1),
+ (tqlayout.getBarPosition(barNo + 1) - x)),
+ tqlayout.isBarCorrectOnStaff(*this, barNo - 1),
currentTimeSignature,
barNo,
showBarNo);
@@ -745,7 +745,7 @@ LinedStaff::insertBar(double layoutX, double width, bool isCorrect,
else
line->show();
// The bar lines have to be in order of layout-x (there's no
// such interesting stipulation for beat or connecting lines)
BarLineList::iterator insertPoint = lower_bound
(m_barLines.begin(), m_barLines.end(), line, compareBars);
@@ -782,7 +782,7 @@ LinedStaff::insertBar(double layoutX, double width, bool isCorrect,
TQFont font;
font.setPixelSize(m_resolution * 3 / 2);
TQFontMetrics metrics(font);
- TQString text = TQString("%1").arg(barNo + 1);
+ TQString text = TQString("%1").tqarg(barNo + 1);
TQCanvasItem *barNoText = new TQCanvasText(text, font, m_canvas);
barNoText->setX(x);
@@ -1110,10 +1110,10 @@ LinedStaff::getLayoutXOfInsertCursor() const
}
timeT
-LinedStaff::getInsertCursorTime(HorizontalLayoutEngine &layout) const
+LinedStaff::getInsertCursorTime(HorizontalLayoutEngine &tqlayout) const
{
if (m_insertCursorTimeValid) return m_insertCursorTime;
- return layout.getTimeForX(getLayoutXOfInsertCursor());
+ return tqlayout.getTimeForX(getLayoutXOfInsertCursor());
}
void
@@ -1141,10 +1141,10 @@ LinedStaff::setPointerPosition(double canvasX, int canvasY)
}
void
-LinedStaff::setPointerPosition(HorizontalLayoutEngine &layout,
+LinedStaff::setPointerPosition(HorizontalLayoutEngine &tqlayout,
timeT time)
{
- setPointerPosition(layout.getXForTime(time));
+ setPointerPosition(tqlayout.getXForTime(time));
}
void
@@ -1176,10 +1176,10 @@ LinedStaff::setInsertCursorPosition(double canvasX, int canvasY)
}
void
-LinedStaff::setInsertCursorPosition(HorizontalLayoutEngine &layout,
+LinedStaff::setInsertCursorPosition(HorizontalLayoutEngine &tqlayout,
timeT time)
{
- double x = layout.getXForTime(time);
+ double x = tqlayout.getXForTime(time);
LinedStaffCoords coords = getCanvasCoordsForLayoutCoords(x, 0);
setInsertCursorPosition(coords.first, coords.second);
m_insertCursorTime = time;
@@ -745,7 +745,7 @@ LinedStaff::insertBar(double layoutX, double width, bool isCorrect,
else
line->show();
- // The bar lines have to be in order of layout-x (there's no
+ // The bar lines have to be in order of tqlayout-x (there's no
// such interesting stipulation for beat or connecting lines)
BarLineList::iterator insertPoint = lower_bound
diff --git a/src/gui/general/LinedStaff.h b/src/gui/general/LinedStaff.h
index 0ebdf5f..3dff372 100644
--- a/src/gui/general/LinedStaff.h
+++ b/src/gui/general/LinedStaff.h
@@ -87,7 +87,7 @@ public:
protected:
/**
* Create a new LinedStaff for the given Segment, with a
- * linear layout.
+ * linear tqlayout.
*
* \a id is an arbitrary id for the staff in its view,
* not used within the LinedStaff implementation but
@@ -104,7 +104,7 @@ protected:
/**
* Create a new LinedStaff for the given Segment, with a
- * page layout.
+ * page tqlayout.
*
* \a id is an arbitrary id for the staff in its view,
* not used within the LinedStaff implementation but
@@ -117,7 +117,7 @@ protected:
* staff line should be
*
* \a pageWidth is the width of a page, to determine
* when to break lines for page layout
*
* \a rowsPerPage is the number of rows to a page, or zero
* for a single continuous page
@@ -131,7 +131,7 @@ protected:
/**
* Create a new LinedStaff for the given Segment, with
* either page or linear layout.
*/
LinedStaff(TQCanvas *, Segment *, SnapGrid *,
int id, int resolution, int lineThickness, PageMode pageMode,
@@ -304,14 +304,14 @@ public:
virtual int getTitleHeight() const;
/**
* Returns the width of the entire staff after layout. Call
* this only after you've done the full sizeStaff/positionElements
* procedure.
*/
virtual double getTotalWidth() const;
/**
* Returns the height of the entire staff after layout. Call
* this only after you've done the full sizeStaff/positionElements
* procedure. If there are multiple rows, this will be the
* height of all rows, including any space between rows that
@@ -383,26 +383,26 @@ public:
virtual void setCurrent(bool current);
/**
* Move the playback pointer to the layout-X coordinate
* corresponding to the given time, and show it.
*/
virtual void setPointerPosition
(HorizontalLayoutEngine&, timeT);
/**
* Move the playback pointer to the layout-X coordinate
* corresponding to the given canvas coordinates, and show it.
*/
virtual void setPointerPosition(double x, int y);
/**
* Move the playback pointer to the given layout-X
* coordinate, and show it.
*/
virtual void setPointerPosition(double x);
/**
* Returns the layout-X coordinate corresponding to the current
* position of the playback pointer.
*/
virtual double getLayoutXOfPointer() const;
@@ -419,19 +419,19 @@ public:
virtual void hidePointer();
/**
* Move the insertion cursor to the layout-X coordinate
* corresponding to the given time, and show it.
*/
virtual void setInsertCursorPosition(HorizontalLayoutEngine&, timeT);
/**
* Move the insertion cursor to the layout-X coordinate
* corresponding to the given canvas coordinates, and show it.
*/
virtual void setInsertCursorPosition(double x, int y);
/**
* Returns the layout-X coordinate corresponding to the current
* position of the insertion cursor. Returns -1 if this staff
* is not current or there is some other problem.
*/
@@ -454,8 +454,8 @@ public:
virtual void hideInsertCursor();
/**
* Query the given horizontal layout object (which is assumed to
* have just completed its layout procedure) to determine the
* required extents of the staff and the positions of the bars,
* and create the bars and staff lines accordingly. It may be
* called either before or after renderElements and/or
@@ -464,7 +464,7 @@ public:
* No bars or staff lines will appear unless this method has
* been called.
*/
- virtual void sizeStaff(HorizontalLayoutEngine& layout);
+ virtual void sizeStaff(HorizontalLayoutEngine& tqlayout);
/**
* Generate or re-generate sprites for all the elements between
@@ -486,9 +486,9 @@ public:
/**
* Assign suitable coordinates to the elements on the staff
* between the start and end times, based entirely on the layout
* X and Y coordinates they were given by the horizontal and
* vertical layout processes.
*
* The implementation is free to render any elements it
* chooses in this method as well.
@@ -519,7 +519,7 @@ public:
* Also return the clef and key in force at these coordinates.
*
* The default implementation should suit for subclasses that only
* show a single element per layout X coordinate.
*/
virtual ViewElementList::iterator getClosestElementToCanvasCoords
(double x, int y,
@@ -533,7 +533,7 @@ public:
/**
* Return an iterator pointing to the nearest view element to the
- * given layout x-coordinate.
+ * given tqlayout x-coordinate.
*
* If notesAndRestsOnly is true, do not return any view element
* other than a note or rest.
@@ -564,7 +564,7 @@ public:
*
*
* The default implementation should suit for subclasses that only
* show a single element per layout X coordinate.
*/
virtual ViewElementList::iterator getElementUnderCanvasCoords
(double x, int y, Event *&clef, Event *&key) {
@@ -627,10 +627,10 @@ public:
protected:
// Methods that the subclass may (indeed, should) use to convert
// between the layout coordinates of elements and their canvas
// coordinates. These are deliberately not virtual.
// Note that even linear-layout staffs have multiple rows; their
// rows all have the same y coordinate but increasing x
// coordinates, instead of the other way around. (The only reason
// for this is that it seems to be more efficient from the TQCanvas
@@ -682,7 +682,7 @@ protected:
// signatures, override the deleteTimeSignatures and
// insertTimeSignature methods. For repeated clefs and keys at
// the start of each row, override deleteRepeatedClefsAndKeys
// and insertRepeatedClefAndKey, but note that your layout class
// will need to allot the space for them separately.
virtual void resizeStaffLines();
@@ -737,7 +737,7 @@ protected:
ItemMatrix m_staffLines;
ItemList m_staffConnectingLines;
- typedef std::pair<double, TQCanvasItem *> LineRec; // layout-x, line
+ typedef std::pair<double, TQCanvasItem *> LineRec; // tqlayout-x, line
typedef FastVector<LineRec> LineRecList;
typedef FastVector<BarLine *> BarLineList;//!!! should be multiset I reckon
static bool compareBars(const BarLine *, const BarLine *);
@@ -117,7 +117,7 @@ protected:
*
* \a pageWidth is the width of a page, to determine
- * when to break lines for page layout
+ * when to break lines for page tqlayout
*
* \a rowsPerPage is the number of rows to a page, or zero
@@ -131,7 +131,7 @@ protected:
/**
* Create a new LinedStaff for the given Segment, with
- * either page or linear layout.
+ * either page or linear tqlayout.
*/
LinedStaff(TQCanvas *, Segment *, SnapGrid *,
@@ -304,14 +304,14 @@ public:
virtual int getTitleHeight() const;
/**
- * Returns the width of the entire staff after layout. Call
+ * Returns the width of the entire staff after tqlayout. Call
* this only after you've done the full sizeStaff/positionElements
* procedure.
@@ -304,14 +304,14 @@ public:
virtual double getTotalWidth() const;
/**
- * Returns the height of the entire staff after layout. Call
+ * Returns the height of the entire staff after tqlayout. Call
* this only after you've done the full sizeStaff/positionElements
* procedure. If there are multiple rows, this will be the
@@ -383,26 +383,26 @@ public:
virtual void setCurrent(bool current);
/**
- * Move the playback pointer to the layout-X coordinate
+ * Move the playback pointer to the tqlayout-X coordinate
* corresponding to the given time, and show it.
*/
@@ -383,26 +383,26 @@ public:
(HorizontalLayoutEngine&, timeT);
/**
- * Move the playback pointer to the layout-X coordinate
+ * Move the playback pointer to the tqlayout-X coordinate
* corresponding to the given canvas coordinates, and show it.
*/
@@ -383,26 +383,26 @@ public:
virtual void setPointerPosition(double x, int y);
/**
- * Move the playback pointer to the given layout-X
+ * Move the playback pointer to the given tqlayout-X
* coordinate, and show it.
*/
@@ -383,26 +383,26 @@ public:
virtual void setPointerPosition(double x);
/**
- * Returns the layout-X coordinate corresponding to the current
+ * Returns the tqlayout-X coordinate corresponding to the current
* position of the playback pointer.
*/
@@ -419,19 +419,19 @@ public:
virtual void hidePointer();
/**
- * Move the insertion cursor to the layout-X coordinate
+ * Move the insertion cursor to the tqlayout-X coordinate
* corresponding to the given time, and show it.
*/
@@ -419,19 +419,19 @@ public:
virtual void setInsertCursorPosition(HorizontalLayoutEngine&, timeT);
/**
- * Move the insertion cursor to the layout-X coordinate
+ * Move the insertion cursor to the tqlayout-X coordinate
* corresponding to the given canvas coordinates, and show it.
*/
@@ -419,19 +419,19 @@ public:
virtual void setInsertCursorPosition(double x, int y);
/**
- * Returns the layout-X coordinate corresponding to the current
+ * Returns the tqlayout-X coordinate corresponding to the current
* position of the insertion cursor. Returns -1 if this staff
* is not current or there is some other problem.
@@ -454,8 +454,8 @@ public:
virtual void hideInsertCursor();
/**
- * Query the given horizontal layout object (which is assumed to
- * have just completed its layout procedure) to determine the
+ * Query the given horizontal tqlayout object (which is assumed to
+ * have just completed its tqlayout procedure) to determine the
* required extents of the staff and the positions of the bars,
* and create the bars and staff lines accordingly. It may be
@@ -486,9 +486,9 @@ public:
/**
* Assign suitable coordinates to the elements on the staff
- * between the start and end times, based entirely on the layout
+ * between the start and end times, based entirely on the tqlayout
* X and Y coordinates they were given by the horizontal and
@@ -486,9 +486,9 @@ public:
* X and Y coordinates they were given by the horizontal and
- * vertical layout processes.
+ * vertical tqlayout processes.
*
* The implementation is free to render any elements it
@@ -519,7 +519,7 @@ public:
*
* The default implementation should suit for subclasses that only
- * show a single element per layout X coordinate.
+ * show a single element per tqlayout X coordinate.
*/
virtual ViewElementList::iterator getClosestElementToCanvasCoords
@@ -564,7 +564,7 @@ public:
*
* The default implementation should suit for subclasses that only
- * show a single element per layout X coordinate.
+ * show a single element per tqlayout X coordinate.
*/
virtual ViewElementList::iterator getElementUnderCanvasCoords
@@ -627,10 +627,10 @@ public:
protected:
// Methods that the subclass may (indeed, should) use to convert
- // between the layout coordinates of elements and their canvas
+ // between the tqlayout coordinates of elements and their canvas
// coordinates. These are deliberately not virtual.
@@ -627,10 +627,10 @@ public:
// coordinates. These are deliberately not virtual.
- // Note that even linear-layout staffs have multiple rows; their
+ // Note that even linear-tqlayout staffs have multiple rows; their
// rows all have the same y coordinate but increasing x
// coordinates, instead of the other way around. (The only reason
@@ -682,7 +682,7 @@ protected:
// insertTimeSignature methods. For repeated clefs and keys at
// the start of each row, override deleteRepeatedClefsAndKeys
- // and insertRepeatedClefAndKey, but note that your layout class
+ // and insertRepeatedClefAndKey, but note that your tqlayout class
// will need to allot the space for them separately.
virtual void resizeStaffLines();